yarpdataplayer_fix {#master}
------------------

### Tools

#### yarpdataplayer

* fixed `yarpdataplayer` to interpret the timestamp correctly, dealing with locale issues, as described in [#2558](https://github.com/robotology/yarp/issues/2558). 